@@ -57,8 +57,9 @@ class base:
         self.app_secret = app_secret
 
     def request(self, api_name=None, method="GET",
-                url=None, api_prefix="api/", **kwargs):
-        host_name = "http://bms.microc.cn/shopguide/"
+                url=None, api_prefix="api/", safe=False, **kwargs):
+        protocol = "https" if safe else "http"
+        host_name = f"{protocol}://bms.microc.cn/shopguide/"
         # host_name = "http://test.xxynet.com/shopguide/api/"
         if not url:
             # url is None:generate url use hostname+api_prefix+apiname
@@ -76,7 +77,8 @@ class base:
         # kwargs["headers"] = kwargs.get("headers", {})
         # kwargs["json"] = kwargs.get("json", {})
         # kwargs["data"] = kwargs.get("data", {})
-
+        logger.debug(url)
+        logger.debug(kwargs)
         response = requests.request(
             method=method,
             url=url,
@@ -89,6 +91,7 @@ class base:
             #     "response": response.text,
             # })
             return self.response(response.json())
+        logger.error(response.text)
 
     def response(self, response_raw):
 
